        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==2 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==9 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==10 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==11 && cc==6){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==12 && cc==6){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==13 && cc==6){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==14 && cc==6){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==15 && cc==6){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 14 <strong>control</strong><br>0,1,12,14,22,24,25,27,36,37,41,45,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 14 <br>2,3,8,9,15,17,18,32,34,38,42,43,44,46';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 10 <br>5,7,11,16,19,20,23,28,31,39';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 5 <br>26,30,35,47,48';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>5</strong> representante: <strong>40</strong> miembros: 5 <br>6,13,21,33,40';}
       if(rr==16 && cc==6){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260628 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>6</strong> representante: <strong>29</strong> miembros: 3 <br>4,10,29';}
}
